@@ -17,7 +17,7 @@
 
 #include "dia2code.h"
 
-#define NO_GENERATORS 9
+#define NO_GENERATORS 12
 
 void generate_code_c(batch *b);
 void generate_code_cpp(batch *b);
@@ -28,5 +28,8 @@ void generate_code_python(batch *b);
 void generate_code_php(batch *b);
 void generate_code_shp(batch *b);
 void generate_code_idl(batch *b);
+void generate_code_csharp(batch *b);
+void generate_code_php_five(batch *b);
+void generate_code_ruby(batch *b);
 
-
+void inherit_attributes(umlclasslist, umlattrlist);
